# asterisk_exporter

This package is loosely based on https://github.com/litnimax/asterisk-stats.

## What is this for?

This app creates a Prometheus scrape endpoint that exposes information about peers (ie connections) and channels (ie active "calls").
